@@ -44,8 +44,9 @@ MODE_MAP = {
 
 class MetadataProxyHandler(object):
 
-    def __init__(self, conf):
+    def __init__(self, conf, chassis):
         self.conf = conf
+        self.chassis = chassis
         self.subscribe()
 
     def subscribe(self):
@@ -57,7 +58,8 @@ class MetadataProxyHandler(object):
         # We need to open a connection to OVN SouthBound database for
         # each worker so that we can process the metadata requests.
         self.sb_idl = ovsdb.MetadataAgentOvnSbIdl(
-            tables=('Port_Binding', 'Datapath_Binding')).start()
+            tables=('Port_Binding', 'Datapath_Binding', 'Chassis'),
+            chassis=self.chassis).start()
 
     @webob.dec.wsgify(RequestClass=webob.Request)
     def __call__(self, req):
@@ -174,8 +176,9 @@ class MetadataProxyHandler(object):
 
 class UnixDomainMetadataProxy(object):
 
-    def __init__(self, conf):
+    def __init__(self, conf, chassis):
         self.conf = conf
+        self.chassis = chassis
         agent_utils.ensure_directory_exists_without_file(
             cfg.CONF.metadata_proxy_socket)
 
@@ -200,7 +203,7 @@ class UnixDomainMetadataProxy(object):
     def run(self):
         self.server = agent_utils.UnixDomainWSGIServer(
             'networking-ovn-metadata-agent')
-        self.server.start(MetadataProxyHandler(self.conf),
+        self.server.start(MetadataProxyHandler(self.conf, self.chassis),
                           self.conf.metadata_proxy_socket,
                           workers=self.conf.metadata_workers,
                           backlog=self.conf.metadata_backlog,
