@@ -416,10 +416,12 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
         return network
 
     @db_api.retry_if_session_inactive()
-    def update_network(self, context, id, network):
+    def update_network(self, context, id, network, db_network=None):
         n = network['network']
+        # we dont't use DB objects not belonging to the current active session
+        db_network = db_network if context.session.is_active else None
         with db_api.CONTEXT_WRITER.using(context):
-            network = self._get_network(context, id)
+            network = db_network or self._get_network(context, id)
             # validate 'shared' parameter
             if 'shared' in n:
                 entry = None
@@ -502,7 +504,8 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                 network_db = self._get_network(context, id)
                 network = self._make_network_dict(network_db, context=context)
                 registry.notify(resources.NETWORK, events.PRECOMMIT_DELETE,
-                                self, context=context, network_id=id)
+                                self, context=context, network_id=id,
+                                network=network)
                 # We expire network_db here because precommit deletion
                 # might have left the relationship stale, for example,
                 # if we deleted a segment.
@@ -1309,7 +1312,7 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
         if not validators.is_attr_set(network_id):
             msg = _("network_id must be specified.")
             raise exc.InvalidInput(error_message=msg)
-        if not network_obj.Network.objects_exist(context, id=network_id):
+        if not self._network_exists(context, network_id):
             raise exc.NetworkNotFound(net_id=network_id)
 
         subnetpool = subnetpool_obj.SubnetPool.get_object(context,
@@ -1419,7 +1422,8 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
             port_data['mac_address'] = p.get('mac_address')
         with db_api.CONTEXT_WRITER.using(context):
             # Ensure that the network exists.
-            self._get_network(context, network_id)
+            if not self._network_exists(context, network_id):
+                raise exc.NetworkNotFound(net_id=network_id)
 
             # Create the port
             db_port = self._create_db_port_obj(context, port_data)
@@ -1457,11 +1461,13 @@ class NeutronDbPluginV2(db_base_plugin_common.DbBasePluginCommon,
                                         new_mac, current_owner)
 
     @db_api.retry_if_session_inactive()
-    def update_port(self, context, id, port):
+    def update_port(self, context, id, port, db_port=None):
+        # we dont't use DB objects not belonging to the current active session
+        db_port = db_port if context.session.is_active else None
         new_port = port['port']
 
         with db_api.CONTEXT_WRITER.using(context):
-            db_port = self._get_port(context, id)
+            db_port = db_port or self._get_port(context, id)
             new_mac = new_port.get('mac_address')
             self._validate_port_for_update(context, db_port, new_port, new_mac)
             # Note: _make_port_dict is called here to load extension data
