@@ -18,8 +18,8 @@ import itertools
 from neutron_lib import constants
 from neutron_lib.db import utils as db_utils
 from neutron_lib import exceptions as n_exc
+from neutron_lib.objects import common_types
 from oslo_versionedobjects import fields as obj_fields
-from six.moves import range as six_range
 from sqlalchemy import and_
 from sqlalchemy import not_
 from sqlalchemy import or_
@@ -37,7 +37,6 @@ from neutron.db.models.plugins.ml2 import vxlanallocation as vxlan_alloc_model
 from neutron.db.models import segment as segments_model
 from neutron.db import models_v2
 from neutron.objects import base
-from neutron.objects import common_types
 
 
 models_map = {
@@ -197,8 +196,8 @@ class NetworkSegmentRange(base.NeutronDbObject):
                                      _filters['physical_network'])
             segment_ids = set([])
             for shared_range in shared_ranges.all():
-                segment_ids.update(set(six_range(shared_range.minimum,
-                                                 shared_range.maximum + 1)))
+                segment_ids.update(set(range(shared_range.minimum,
+                                             shared_range.maximum + 1)))
             if not segment_ids:
                 return []
 
@@ -214,8 +213,8 @@ class NetworkSegmentRange(base.NeutronDbObject):
                     _filters['physical_network'])
 
             for other_project_range in other_project_ranges.all():
-                _set = set(six_range(other_project_range.minimum,
-                                     other_project_range.maximum + 1))
+                _set = set(range(other_project_range.minimum,
+                                 other_project_range.maximum + 1))
                 segment_ids.difference_update(_set)
 
             # NOTE(ralonsoh): https://stackoverflow.com/questions/4628333/
