@@ -33,11 +33,25 @@ from neutron.common.ovn import utils
 from neutron.conf.plugins.ml2.drivers.ovn import ovn_conf as cfg
 from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import commands as cmd
 from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import ovsdb_monitor
+from neutron.plugins.ml2.drivers.ovn.mech_driver.ovsdb import worker
 
 
 LOG = log.getLogger(__name__)
 
 
+# Override wait_for_change to not use a timeout so we always try to reconnect
+def wait_for_change(idl_, timeout, seqno=None):
+    if seqno is None:
+        seqno = idl_.change_seqno
+        while idl_.change_seqno == seqno and not idl_.run():
+            poller = idlutils.poller.Poller()
+            idl_.wait(poller)
+            poller.block()
+
+
+idlutils.wait_for_change = wait_for_change
+
+
 class OvnNbTransaction(idl_trans.Transaction):
 
     def __init__(self, *args, **kwargs):
@@ -122,45 +136,35 @@ class OvsdbConnectionUnavailable(n_exc.ServiceUnavailable):
 # Retry forever to get the OVN NB and SB IDLs. Wait 2^x * 1 seconds between
 # each retry, up to 'max_interval' seconds, then interval will be fixed
 # to 'max_interval' seconds afterwards. The default 'max_interval' is 180.
-def get_ovn_idls(driver, trigger, binding_events=False):
+def get_ovn_idls(driver, trigger):
     @tenacity.retry(
         wait=tenacity.wait_exponential(
             max=cfg.get_ovn_ovsdb_retry_max_interval()),
         reraise=True)
-    def get_ovn_idl_retry(cls):
+    def get_ovn_idl_retry(api_cls):
         trigger_class = utils.get_method_class(trigger)
         LOG.info('Getting %(cls)s for %(trigger)s with retry',
-                 {'cls': cls.__name__, 'trigger': trigger_class.__name__})
-        return cls(get_connection(cls, trigger, driver, binding_events))
+                 {'cls': api_cls.__name__, 'trigger': trigger_class.__name__})
+        return api_cls.from_worker(trigger_class, driver)
 
     vlog.use_python_logger(max_level=cfg.get_ovn_ovsdb_log_level())
     return tuple(get_ovn_idl_retry(c) for c in (OvsdbNbOvnIdl, OvsdbSbOvnIdl))
 
 
-def get_connection(db_class, trigger=None, driver=None, binding_events=False):
-    if db_class == OvsdbNbOvnIdl:
-        args = (cfg.get_ovn_nb_connection(), 'OVN_Northbound')
-    elif db_class == OvsdbSbOvnIdl:
-        args = (cfg.get_ovn_sb_connection(), 'OVN_Southbound')
-
-    if binding_events:
-        if db_class == OvsdbNbOvnIdl:
-            idl_ = ovsdb_monitor.OvnNbIdl.from_server(*args, driver=driver)
-        else:
-            idl_ = ovsdb_monitor.OvnSbIdl.from_server(*args, driver=driver)
-    else:
-        if db_class == OvsdbNbOvnIdl:
-            idl_ = ovsdb_monitor.BaseOvnIdl.from_server(*args)
-        else:
-            idl_ = ovsdb_monitor.BaseOvnSbIdl.from_server(*args)
-
-    return connection.Connection(idl_, timeout=cfg.get_ovn_ovsdb_timeout())
-
-
 class OvsdbNbOvnIdl(nb_impl_idl.OvnNbApiIdlImpl, Backend):
     def __init__(self, connection):
         super(OvsdbNbOvnIdl, self).__init__(connection)
 
+    @classmethod
+    def from_worker(cls, worker_class, driver=None):
+        args = (cfg.get_ovn_nb_connection(), 'OVN_Northbound')
+        if worker_class == worker.MaintenanceWorker:
+            idl_ = ovsdb_monitor.BaseOvnIdl.from_server(*args)
+        else:
+            idl_ = ovsdb_monitor.OvnNbIdl.from_server(*args, driver=driver)
+        conn = connection.Connection(idl_, timeout=cfg.get_ovn_ovsdb_timeout())
+        return cls(conn)
+
     @property
     def nb_global(self):
         return next(iter(self.tables['NB_Global'].rows.values()))
@@ -721,6 +725,16 @@ class OvsdbSbOvnIdl(sb_impl_idl.OvnSbApiIdlImpl, Backend):
     def __init__(self, connection):
         super(OvsdbSbOvnIdl, self).__init__(connection)
 
+    @classmethod
+    def from_worker(cls, worker_class, driver=None):
+        args = (cfg.get_ovn_sb_connection(), 'OVN_Southbound')
+        if worker_class == worker.MaintenanceWorker:
+            idl_ = ovsdb_monitor.BaseOvnSbIdl.from_server(*args)
+        else:
+            idl_ = ovsdb_monitor.OvnSbIdl.from_server(*args, driver=driver)
+        conn = connection.Connection(idl_, timeout=cfg.get_ovn_ovsdb_timeout())
+        return cls(conn)
+
     def _get_chassis_physnets(self, chassis):
         bridge_mappings = chassis.external_ids.get('ovn-bridge-mappings', '')
         mapping_dict = helpers.parse_mappings(bridge_mappings.split(','),
@@ -803,9 +817,24 @@ class OvsdbSbOvnIdl(sb_impl_idl.OvnSbApiIdlImpl, Backend):
         rows = self.db_list_rows('Port_Binding').execute(check_error=True)
         # TODO(twilson) It would be useful to have a db_find that takes a
         # comparison function
-        return [r for r in rows
-                if (r.mac and str(r.datapath.uuid) == network) and
-                ip_address in r.mac[0].split(' ')]
+
+        def check_net_and_ip(port):
+            # If the port is not bound to any chassis it is not relevant
+            if not port.chassis:
+                return False
+
+            # TODO(dalvarez): Remove the comparison to port.datapath.uuid in Y
+            # cycle when we are sure that all namespaces will be created with
+            # the Neutron network UUID and not anymore with the OVN datapath
+            # UUID.
+            is_in_network = lambda port: (
+                str(port.datapath.uuid) == network or
+                utils.get_network_name_from_datapath(port.datapath) == network)
+
+            return port.mac and is_in_network(port) and (
+                    ip_address in port.mac[0].split(' '))
+
+        return [r for r in rows if check_net_and_ip(r)]
 
     def set_port_cidrs(self, name, cidrs):
         # TODO(twilson) add if_exists to db commands
